# PyWrithe

All Python package to compute closed curve's writhe.

Supports both numpy and jax.numpy.


# Algorithm concept

Klenin K., Langowski J. *Computation of writhe in modeling of supercoiled DNA*; Biopolymers (2000)

https://doi.org/10.1002/1097-0282(20001015)54:5<307::AID-BIP20>3.0.CO;2-Y

# License

This software is licensed under MIT license

Copyright (c) Radost Waszkiewicz (2021)
